@@ -69,7 +69,9 @@ def commands():
     type=str,
     default=None,
 )
+@click.option("-d", "--datacenter", help="Datacenter", type=str, default=None)
 @add_options(_vpn_options)
+@click.option("-k", "--kitchen", help="iDAC Kitchen sandbox location", type=str, default=None)
 @click.argument("recipe_path")
 @click.argument("recipe_name")
 @with_controller
@@ -116,6 +118,11 @@ async def create(controller, recipe_path, recipe_name, out_path, vpn, **kwargs):
     if "datacenter" in filtered:
         sd.set("datacenter", filtered["datacenter"])
 
+    if "kitchen" in filtered:
+        # user would like to execute recipe in a Kitchen sandbox
+        sd.set("location", filtered["kitchen"])
+        sd.set("recipeMode", "worker")
+
     req = IDACRequestAsync(session_data=sd, controller=controller, vpn=vpn)
     state, redirect = await req.create(request_type=IDACRequestType[filtered.get("type", "SIMPLE")])
 
