@@ -23,7 +23,20 @@ _controller_options = [
         "-A",
         "--auth",
         type=str,
-        help="Token if Auth Type is BEARER, base64 string if BASIC. Ignored for other auth types",
+        help=(
+            "Token if Auth Type is BEARER or WORKER, base64 string if BASIC. Ignored for other auth"
+            " types"
+        ),
+    ),
+    click.option(
+        "--worker-id",
+        type=str,
+        help="Worker id for the Worker auth type",
+    ),
+    click.option(
+        "--worker-secret",
+        type=str,
+        help="Worker secret for the Worker auth type",
     ),
     click.option("-V", "--api-version", default=None, help="API version to use"),
 ]
@@ -31,7 +44,17 @@ _controller_options = [
 
 def with_controller(func):
     @wraps(func)
-    def wrapper(*args, controller_url, controller_proto, auth_type, auth, api_version, **kwargs):
+    def wrapper(
+        *args,
+        controller_url,
+        controller_proto,
+        auth_type,
+        auth,
+        worker_id,
+        worker_secret,
+        api_version,
+        **kwargs
+    ):
         controller = IDACControllerAsync(
             **filter_dict(
                 {
@@ -39,6 +62,8 @@ def with_controller(func):
                     "url": controller_url,
                     "auth_type": IDACAuthType[auth_type] if auth_type else None,
                     "auth": auth,
+                    "worker_id": worker_id,
+                    "worker_secret": worker_secret,
                     "api_version": api_version,
                 },
                 lambda elem: bool(elem[1]),
