@@ -1,6 +1,22 @@
 import ujson
 from typing import List
 import asyncclick as click
+import logging
+
+from idac_sdk.log import logger
+
+
+_debug_options = [
+    click.option("--debug", default=False, is_flag=True, help="Enable debug", hidden=True)
+]
+
+
+def set_logger_level(debug: bool) -> None:
+    if debug:
+        logger.setLevel(logging.DEBUG)
+        logger.debug("Debug level enabled")
+    else:
+        logger.setLevel(logging.WARN)
 
 
 def add_options(options):
